Author: dannas
Date: Mon Jul 19 09:01:57 2010
New Revision: 965389

URL: http://svn.apache.org/viewvc?rev=965389&view=rev
Log:
Give more descriptive names for variables representing the original 
targets of a diff operation.

No semantic changes.

* subversion/libsvn_client/diff.c
  (adjust_paths_for_diff_labels): Replace path1 and path2 with 
    orig_path_1 and orig_path_2. 

Modified:
    subversion/trunk/subversion/libsvn_client/diff.c

Modified: subversion/trunk/subversion/libsvn_client/diff.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/diff.c?rev=965389&r1=965388&r2=965389&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/diff.c (original)
+++ subversion/trunk/subversion/libsvn_client/diff.c Mon Jul 19 09:01:57 2010
@@ -190,22 +190,22 @@ maybe_append_eol(const svn_string_t *tok
     }
 }
 
 /* Adjust PATH, PATH1 and PATH2, representing the changed file and the two
  * original targets passed to the diff command, to handle the case when
  * we're dealing with different anchors. RELATIVE_TO_DIR is the directory
  * the diff target should be considered relative to. All allocations are done
  * in POOL. */
 static svn_error_t *
 adjust_paths_for_diff_labels(const char **path,
-                             const char **path1,
-                             const char **path2,
+                             const char **orig_path_1,
+                             const char **orig_path_2,
                              const char *relative_to_dir,
                              apr_pool_t *pool)
 {
   apr_size_t len;
   const char *new_path = *path;
-  const char *new_path1 = *path1;
-  const char *new_path2 = *path2;
+  const char *new_path1 = *orig_path_1;
+  const char *new_path2 = *orig_path_2;
 
   /* ### Holy cow.  Due to anchor/target weirdness, we can't
      simply join diff_cmd_baton->orig_path_1 with path, ditto for
@@ -274,8 +274,8 @@ adjust_paths_for_diff_labels(const char 
         return MAKE_ERR_BAD_RELATIVE_PATH(new_path2, relative_to_dir);
     }
   *path = new_path;
-  *path1 = new_path1;
-  *path2 = new_path2;
+  *orig_path_1 = new_path1;
+  *orig_path_2 = new_path2;
 
   return SVN_NO_ERROR;
 }
@@ -190,22 +190,22 @@ maybe_append_eol(const svn_string_t *tok
 }
 
-/* Adjust PATH, PATH1 and PATH2, representing the changed file and the two
- * original targets passed to the diff command, to handle the case when
- * we're dealing with different anchors. RELATIVE_TO_DIR is the directory
- * the diff target should be considered relative to. All allocations are done
- * in POOL. */
+/* Adjust PATH, ORIG_PATH_1 and ORIG_PATH_2, representing the changed file
+ * and the two original targets passed to the diff command, to handle the
+ * case when we're dealing with different anchors. RELATIVE_TO_DIR is the
+ * directory the diff target should be considered relative to. All
+ * allocations are done in POOL. */
 static svn_error_t *
 adjust_paths_for_diff_labels(const char **path,


Reply via email to